@@ -30,4 +30,6 @@ from chargebee.models.promotional_credit import PromotionalCredit
 from chargebee.models.virtual_bank_account import VirtualBankAccount
 from chargebee.models.contact import Contact
 from chargebee.models.export import Export
+from chargebee.models.gift import Gift
+from chargebee.models.quote import Quote
 from chargebee.models.content import Content
