@@ -5,10 +5,10 @@ from chargebee import APIError
 
 class Card(Model):
 
-    fields = ["customer_id", "status", "gateway", "first_name", "last_name", "iin", "last4", \
-    "card_type", "funding_type", "expiry_month", "expiry_year", "billing_addr1", "billing_addr2", \
-    "billing_city", "billing_state_code", "billing_state", "billing_country", "billing_zip", "ip_address", \
-    "masked_number"]
+    fields = ["payment_source_id", "status", "gateway", "gateway_account_id", "first_name", \
+    "last_name", "iin", "last4", "card_type", "funding_type", "expiry_month", "expiry_year", "issuing_country", \
+    "billing_addr1", "billing_addr2", "billing_city", "billing_state_code", "billing_state", "billing_country", \
+    "billing_zip", "ip_address", "customer_id", "masked_number"]
 
 
     @staticmethod
