@@ -39,6 +39,22 @@ class HostedPage(Model):
     def collect_now(params, env=None, headers=None):
         return request.send('post', request.uri_path("hosted_pages","collect_now"), params, env, headers)
 
+    @staticmethod
+    def extend_subscription(params, env=None, headers=None):
+        return request.send('post', request.uri_path("hosted_pages","extend_subscription"), params, env, headers)
+
+    @staticmethod
+    def checkout_gift(params, env=None, headers=None):
+        return request.send('post', request.uri_path("hosted_pages","checkout_gift"), params, env, headers)
+
+    @staticmethod
+    def claim_gift(params, env=None, headers=None):
+        return request.send('post', request.uri_path("hosted_pages","claim_gift"), params, env, headers)
+
+    @staticmethod
+    def retrieve_agreement_pdf(params, env=None, headers=None):
+        return request.send('post', request.uri_path("hosted_pages","retrieve_agreement_pdf"), params, env, headers)
+
     @staticmethod
     def acknowledge(id, env=None, headers=None):
         return request.send('post', request.uri_path("hosted_pages",id,"acknowledge"), None, env, headers)
