@@ -5,7 +5,7 @@ from chargebee import APIError
 
 class Invoice(Model):
     class LineItem(Model):
-      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "is_taxed", "tax_amount", "tax_rate", "amount", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
       pass
     class Discount(Model):
       fields = ["amount", "description", "entity_type", "entity_id"]
@@ -19,6 +19,9 @@ class Invoice(Model):
     class LineItemTax(Model):
       fields = ["line_item_id", "tax_name", "tax_rate", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
       pass
+    class LineItemTier(Model):
+      fields = ["line_item_id", "starting_unit", "ending_unit", "quantity_used", "unit_amount"]
+      pass
     class LinkedPayment(Model):
       fields = ["txn_id", "applied_amount", "applied_at", "txn_status", "txn_date", "txn_amount"]
       pass
@@ -32,7 +35,7 @@ class Invoice(Model):
       fields = ["cn_id", "cn_reason_code", "cn_date", "cn_total", "cn_status"]
       pass
     class LinkedOrder(Model):
-      fields = ["id", "status", "reference_id", "fulfillment_status", "batch_id", "created_at"]
+      fields = ["id", "document_number", "status", "order_type", "reference_id", "fulfillment_status", "batch_id", "created_at"]
       pass
     class Note(Model):
       fields = ["entity_type", "note", "entity_id"]
@@ -48,10 +51,10 @@ class Invoice(Model):
     "price_type", "date", "due_date", "net_term_days", "currency_code", "total", "amount_paid", \
     "amount_adjusted", "write_off_amount", "credits_applied", "amount_due", "paid_at", "dunning_status", \
     "next_retry_at", "voided_at", "resource_version", "updated_at", "sub_total", "tax", "first_invoice", \
-    "has_advance_charges", "expected_payment_date", "amount_to_collect", "round_off_amount", "line_items", \
-    "discounts", "line_item_discounts", "taxes", "line_item_taxes", "linked_payments", "applied_credits", \
-    "adjustment_credit_notes", "issued_credit_notes", "linked_orders", "notes", "shipping_address", \
-    "billing_address", "deleted"]
+    "has_advance_charges", "term_finalized", "is_gifted", "expected_payment_date", "amount_to_collect", \
+    "round_off_amount", "line_items", "discounts", "line_item_discounts", "taxes", "line_item_taxes", \
+    "line_item_tiers", "linked_payments", "applied_credits", "adjustment_credit_notes", "issued_credit_notes", \
+    "linked_orders", "notes", "shipping_address", "billing_address", "deleted"]
 
 
     @staticmethod
