@@ -5,7 +5,7 @@ from chargebee import APIError
 
 class InvoiceEstimate(Model):
     class LineItem(Model):
-      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "is_taxed", "tax_amount", "tax_rate", "amount", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
       pass
     class Discount(Model):
       fields = ["amount", "description", "entity_type", "entity_id"]
@@ -16,10 +16,14 @@ class InvoiceEstimate(Model):
     class LineItemTax(Model):
       fields = ["line_item_id", "tax_name", "tax_rate", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
       pass
+    class LineItemTier(Model):
+      fields = ["line_item_id", "starting_unit", "ending_unit", "quantity_used", "unit_amount"]
+      pass
     class LineItemDiscount(Model):
       fields = ["line_item_id", "discount_type", "coupon_id", "discount_amount"]
       pass
 
     fields = ["recurring", "price_type", "currency_code", "sub_total", "total", "credits_applied", \
-    "amount_paid", "amount_due", "line_items", "discounts", "taxes", "line_item_taxes", "line_item_discounts"]
+    "amount_paid", "amount_due", "line_items", "discounts", "taxes", "line_item_taxes", "line_item_tiers", \
+    "line_item_discounts", "round_off_amount"]
 
