@@ -6,7 +6,7 @@ from chargebee import APIError
 class PromotionalCredit(Model):
 
     fields = ["id", "customer_id", "type", "amount", "currency_code", "description", "credit_type", \
-    "reference", "closing_balance", "created_at"]
+    "reference", "closing_balance", "done_by", "created_at"]
 
 
     @staticmethod
